@@ -144,8 +144,14 @@ class Field(object):
         self._read_only = read_only
 
     def __repr__(self):
+        if isinstance(self._default, set):
+            # make a py27 and py35 compatible representation. See bug 1771804
+            default = 'set([%s])' % ','.join(sorted([six.text_type(v)
+                                                     for v in self._default]))
+        else:
+            default = str(self._default)
         return '%s(default=%s,nullable=%s)' % (self._type.__class__.__name__,
-                                               self._default, self._nullable)
+                                               default, self._nullable)
 
     @property
     def nullable(self):
@@ -347,9 +353,12 @@ class UUID(StringPattern):
     def coerce(obj, attr, value):
         # FIXME(danms): We should actually verify the UUIDness here
         with warnings.catch_warnings():
-            warnings.simplefilter("once")
+            # Change the warning action only if no other filter exists
+            # for this warning to allow the client to define other action
+            # like 'error' for this warning.
+            warnings.filterwarnings(action="once", append=True)
             try:
-                uuid.UUID(str(value))
+                uuid.UUID("%s" % value)
             except Exception:
                 # This is to ensure no breaking behaviour for current
                 # users
@@ -360,9 +369,11 @@ class UUID(StringPattern):
                               "code to input valid UUIDs or accept "
                               "ValueErrors for invalid UUIDs. See "
                               "https://docs.openstack.org/oslo.versionedobjects/latest/reference/fields.html#oslo_versionedobjects.fields.UUIDField "  # noqa
-                              "for further details" % value, FutureWarning)
+                              "for further details" %
+                              repr(value).encode('utf8'),
+                              FutureWarning)
 
-            return str(value)
+            return "%s" % value
 
 
 class MACAddress(StringPattern):
